@@ -43,14 +43,24 @@ class globalValues:
 # インスタンス生成(import時に実行される)
 gv = globalValues()
 
-def configer(__file__):
+class configer():
+
+    """
+    共通設定クラス
+    """
     
-    # 共通設定(ノーマル)
-    ccfg = cmnConfig()
-    ccfg.getConfig(__file__, 'TestConfig')
+    def __init__(self, tgv, filePath, configFolderName):
+        
+        """
+        コンストラクタ
+        """
+        
+        # 共通設定(ノーマル)
+        ccfg = cmnConfig()
+        ccfg.getConfig(filePath, configFolderName)
 
-    # ロガー設定
-    Logger.setting(ccfg)
+        # ロガー設定
+        Logger.setting(ccfg)
 
-    # 共通設定
-    gv.config = ccfg
+        # 共通設定
+        tgv.config = ccfg
